### `helperfns` **`1.2.1`** (2024-10-12)

We have released a stable version of `helperfns` **`1.2.1`**.

- Well documented.
- Fixed imports and bugs.

### `helperfns` **`1.2.1-alpha`** (2024-10-11)

We have released a new version of `helperfns` **`1.2.1-alpha`** with the following changes:

1. Added a new helper function `plot_wordcloud` in the `helperfns.visualization` module.
2. Enhanced the `helperfns.visualization` module to allow saving plots.

===
helperfns **`1.0.2`**
===

### Release Notes - `helperfns`

We have release the new `helperfns` Version `1.0.2` (`2024-04-08`)

##### Features

- Updated documentation.

===
helperfns **`1.0.1`**
===

### Release Notes - `helperfns`

We have release the new `helperfns` Version `1.0.1` (`2024-03-07`)

##### Features

- Updated documentation.
- Testing the package.
- removed `normalize` image because it not generic.
